@@ -1258,7 +1258,8 @@ class InteractiveSearch(App):
         """异步执行搜索"""
         # 如果搜索已经在进行中，直接返回，防止并发搜索
         if self._search_in_progress:
-            self.notify("搜索正在进行中，请稍候...")
+            # 进度提示弱化为 info，减少噪音
+            self.notify("搜索正在进行中，请稍候...", severity="info")
             return
             
         # 设置搜索锁
@@ -1313,7 +1314,7 @@ class InteractiveSearch(App):
                 
                 # 搜索完成后清除状态显示
                 suggestion_display.update("搜索完成")
-                self.notify("搜索完成")
+                self.notify("搜索完成", severity="success")
                 
                 # 如果历史记录可见，刷新历史记录显示
                 if self.history_visible:
@@ -1328,7 +1329,7 @@ class InteractiveSearch(App):
                 search_button.disabled = False
         except Exception as e:
             # 捕获所有异常，确保即使在图表上按回车键也不会阻塞程序
-            self.notify(f"搜索操作出错: {str(e)}")
+            self.notify(f"搜索操作出错: {str(e)}", severity="error")
             # 记录错误到日志
             with open("search_error.log", "a") as f:
                 f.write(f"[{datetime.now()}] 搜索错误: {str(e)}\n")
@@ -1371,7 +1372,7 @@ class InteractiveSearch(App):
         if event.button.id == "search-button":
             # 检查是否已经有搜索在进行中
             if self._search_in_progress:
-                self.notify("搜索正在进行中，请稍候...", severity="warning")
+                self.notify("搜索正在进行中，请稍候...", severity="info")
                 return
             # 创建管理的异步任务来执行搜索
             self.create_managed_task(self.action_search())
@@ -1385,7 +1386,7 @@ class InteractiveSearch(App):
         self.action_toggle_history()
         # 检查是否已经有搜索在进行中
         if self._search_in_progress:
-            self.notify("搜索正在进行中，请稍候...", severity="warning")
+            self.notify("搜索正在进行中，请稍候...", severity="info")
             return
         # 使用管理的异步任务执行搜索
         self.create_managed_task(self.action_search())
