@@ -47,14 +47,14 @@ class InteractiveChatApp(App):
     CSS = CSS
     
     BINDINGS = [
-        ("ctrl+q", "quit", "退出"),
-        ("ctrl+c", "clear_chat", "清空对话"),
-        ("ctrl+n", "clear_chat", "新会话"),
-        ("ctrl+t", "show_tools", "显示工具"),
-        ("ctrl+i", "focus_input", "聚焦输入框"),
-        ("ctrl+h", "show_session_history", "历史会话"),
-        ("ctrl+m", "show_model_config", "模型配置"),
-        ("ctrl+k", "show_context", "上下文"),
+        ("q", "quit", "退出"),
+        ("c", "clear_chat", "清空对话"),
+        ("n", "clear_chat", "新会话"),
+        ("t", "show_tools", "显示工具"),
+        ("i", "focus_input", "聚焦输入框"),
+        ("h", "show_session_history", "历史会话"),
+        ("m", "show_model_config", "模型配置"),
+        ("k", "show_context", "上下文"),
     ]
     
     def __init__(self, **kwargs):
@@ -74,15 +74,43 @@ class InteractiveChatApp(App):
         # 对应函数名：list_assets, list_queryable_assets, search_data_for_log, search_data_for_metric, get_docs
         self.enabled_tools = {
             "list_assets",
-            "list_queryable_assets",
-            "search_data_for_log",
-            "search_data_for_metric",
-            "get_repository_fields",
+            "list_queryable",
+            "search_data",
+            "get_repo_fields",
             "get_docs",
-            # 图表显示：允许模型调用 Textual 图表渲染
-            # "display_chart_textual",
         }
         
+        # 通知过滤配置：仅展示重要信息（error/warning/success）
+        self._important_severities = {"error", "warning", "success"}
+        # 明显的调试/噪音标记，统一屏蔽
+        self._debug_markers = ("DEBUG", "🧪", "🔧", "➡️", "🔗", "⚙️", "📩", "🛠️", "🧹", "🔁")
+
+    def notify(self, message, **kwargs):
+        """统一过滤通知，仅保留重要提示。
+
+        规则：
+        - 严重级别在 error/warning/success 的提示保留；
+        - 包含明显调试标记（如 DEBUG/🧪/🔧 等）的提示直接忽略；
+        - 其他 info 级别或未设严重级别的提示忽略。
+        """
+        try:
+            severity = kwargs.get("severity", "info")
+            text = str(message)
+        except Exception:
+            severity = kwargs.get("severity", "info")
+            text = message
+
+        # 屏蔽明显的调试/噪音提示
+        if any(marker in (text or "") for marker in self._debug_markers):
+            return
+
+        # 仅保留重要等级
+        if severity not in self._important_severities:
+            return
+
+        # 透传给父类实现
+        return super().notify(message, **kwargs)
+        
     def compose(self) -> ComposeResult:
         """构建应用UI"""
         yield Header()
@@ -118,7 +146,7 @@ class InteractiveChatApp(App):
     def _add_welcome_message(self):
         """添加欢迎消息"""
         chat_history = self.query_one("#chat-history", ChatHistoryWidget)
-        welcome_msg = """👋 欢迎使用AI智能对话助手！
+        welcome_msg = f"""👋 欢迎使用KetaOps AI智能对话助手！
 
 我可以帮助您：
 - 📊 数据查询和分析
@@ -126,7 +154,15 @@ class InteractiveChatApp(App):
 - 📈 资源监控
 - 🛠️ 系统管理
 
-请输入您的问题，我会尽力为您提供帮助。您也可以按 Ctrl+T 查看可用的工具列表。"""
+推荐示例：
+- 对当前系统进行巡检
+- 查询traceid为xxx的记录，分析其潜在的性能或异常
+- 创建一个repo、soucetype等资源
+- 查询logs_keta仓库中的异常日志并分析
+
+请输入您的问题，我会尽力为您提供帮助。
+
+当前已启用工具：{', '.join([f'`{x}`' for x in self.enabled_tools]) or '无'}。您也可以按 `T` 查看可用的工具列表来启用或关闭工具开关。"""
         
         chat_history.add_message("assistant", welcome_msg)
 
@@ -162,14 +198,15 @@ class InteractiveChatApp(App):
             if chat_history._current_streaming_widget:
                 chat_history.finish_streaming_message("**[已停止响应]**")
             
-            self.notify("已停止AI响应", severity="info")
+            self.notify("已停止AI响应", severity="success")
 
     def on_chat_input_widget_message_sent(self, message: ChatInputWidget.MessageSent) -> None:
         """处理用户发送的消息"""
         if self._chat_in_progress:
             chat_input = self.query_one("#chat-input", ChatInputWidget)
             chat_input.set_loading(False)
-            self.notify("对话正在进行中，请稍候...", severity="warning")
+            # 进度提示弱化，减少噪音
+            self.notify("对话正在进行中，请稍候...", severity="info")
             return
             
         user_message = message.message
@@ -218,6 +255,26 @@ class InteractiveChatApp(App):
                     system_prompt=self.ai_client.system_prompt,
                     model_name=selected_model
                 )
+            # 增强系统提示词：统一工具调用为 auto，并要求“调用一次工具后先分析输出结论，避免重复调用”
+            def _augment_system_prompt(base: str) -> str:
+                rules = (
+                    "你是一个可靠的助手，工具调用策略为自动模式。\n"
+                    "当你决定调用工具时，请遵循以下规则：\n"
+                    "1) 每轮至多调用一个工具；调用后必须基于工具结果进行分析并输出明确文本结论。\n"
+                    "2) 避免连续多次重复调用同一工具或在已具备足够信息时再次调用。\n"
+                    "3) 如工具调用失败，请解释原因并给出替代方案或推断结论。\n"
+                    "4) 仅在明确缺少信息且无法产出结论时，才再次考虑调用工具。\n"
+                    "5) 不要返回只有工具调用而没有任何文本内容的响应。\n"
+                )
+                try:
+                    base = (base or "").strip()
+                except Exception:
+                    base = ""
+                return (base + "\n\n" + rules) if base else rules
+            try:
+                self.ai_client.system_prompt = _augment_system_prompt(self.ai_client.system_prompt)
+            except Exception:
+                pass
             
             # 准备对话历史，应用上下文压缩
             current_message = {"role": "user", "content": user_message}
@@ -390,8 +447,17 @@ class InteractiveChatApp(App):
             except Exception:
                 pass
             
-            max_iterations = 10
+            # 迭代上限改为读取模型配置，默认20
+            try:
+                max_iterations = getattr(self.ai_client.model_config, "max_iterations", 20) or 20
+                if not isinstance(max_iterations, int) or max_iterations <= 0:
+                    max_iterations = 20
+            except Exception:
+                max_iterations = 20
             iteration = 0
+            # 新增：当前用户请求周期内的工具失败屏蔽标志与重复调用去重集合
+            block_tool_retry_for_current_query = False
+            executed_tool_signatures = set()
             
             while iteration < max_iterations:
                 iteration += 1
@@ -428,33 +494,15 @@ class InteractiveChatApp(App):
                 except Exception:
                     pass
                 
-                # 首轮优先使用 auto，由模型自决是否调用工具
+                # 统一使用 auto 策略进行工具调用
                 tool_choice_value = "auto"
-                try:
-                    self.notify(f"⚙️ 使用 tool_choice: {tool_choice_value}", timeout=2)
-                except Exception:
-                    pass
+                tools_for_request = tools
                 response = await self.ai_client.chat_with_tools_async(
                     messages=messages,
-                    tools=tools,
+                    tools=tools_for_request,
                     tool_choice=tool_choice_value
                 )
-                # 若未返回结构化工具调用且语义/历史提示需要工具，则在同轮重试为 required
-                if not response.tool_calls:
-                    need_tools_by_semantic = self._needs_tool_call(user_message) or _should_force_tool_call(messages, user_message)
-                    has_prev_tool_calls = any(
-                        (m.get("role") == "assistant" and (m.get("tool_calls") or [])) for m in self.conversation_history
-                    )
-                    if need_tools_by_semantic or has_prev_tool_calls:
-                        try:
-                            self.notify("🔁 未返回tool_calls，进行required重试", severity="warning", timeout=3)
-                        except Exception:
-                            pass
-                        response = await self.ai_client.chat_with_tools_async(
-                            messages=messages,
-                            tools=tools,
-                            tool_choice="required"
-                        )
+                # 不再使用 required 强制调用，完全依赖 auto 与提示词约束
                 
                 # 调试：响应基础信息
                 try:
@@ -477,10 +525,39 @@ class InteractiveChatApp(App):
                 # 根据启用的工具过滤模型返回的工具调用
                 try:
                     disabled_called_names = []
+                    # 保持与上方一致的过滤，并在禁用轮次下强制清空
                     filtered_tool_calls = [
                         tc for tc in (response.tool_calls or [])
                         if ((tc or {}).get("function", {}).get("name") in self.enabled_tools)
                     ]
+                    # 保持 auto 策略，不再强制清空
+                    # 去重：避免同一函数与相同参数的重复调用（同一用户请求周期内）
+                    try:
+                        import json
+                        dedup = []
+                        for tc in filtered_tool_calls:
+                            fn = (tc or {}).get("function", {})
+                            nm = fn.get("name")
+                            args = fn.get("arguments", "{}")
+                            try:
+                                if isinstance(args, (dict, list)):
+                                    args_norm = json.dumps(args, ensure_ascii=False, sort_keys=True)
+                                else:
+                                    args_norm = str(args)
+                            except Exception:
+                                args_norm = str(args)
+                            sig = f"{nm}:{args_norm}"
+                            if sig in executed_tool_signatures:
+                                try:
+                                    self.notify(f"♻️ 跳过重复工具调用: {nm}", severity="warning", timeout=3)
+                                except Exception:
+                                    pass
+                                continue
+                            executed_tool_signatures.add(sig)
+                            dedup.append(tc)
+                        filtered_tool_calls = dedup
+                    except Exception:
+                        pass
                     # 若存在被禁用的工具调用，告知用户并忽略它们
                     try:
                         disabled_called = [
@@ -490,11 +567,28 @@ class InteractiveChatApp(App):
                         ]
                         disabled_called_names = disabled_called
                         if disabled_called:
+                            # 顶部通知：提示未启用工具被忽略
                             self.notify(
                                 f"🚫 检测到未启用的工具调用已被忽略：{', '.join([n for n in disabled_called if n][:6])}",
                                 severity="warning",
                                 timeout=4
                             )
+                            # 在聊天消息中追加启用指引，保证用户在对话中也能看到
+                            try:
+                                preview = ", ".join([n for n in disabled_called if n][:6])
+                                guidance = (
+                                    f"⚠️ 检测到模型尝试调用未启用的工具：{preview}。该调用已被忽略。\n"
+                                    "请按 `T` 或 `Ctrl+T` 打开工具列表启用所需工具，或继续输入让我在不使用工具的情况下回答。"
+                                )
+                                existing = (assistant_message.get("content") or "")
+                                # 若已有文本回复，则在末尾追加指引；否则直接作为回复内容
+                                if existing.strip():
+                                    sep = "\n\n" if not existing.endswith("\n") else "\n"
+                                    assistant_message["content"] = existing + sep + guidance
+                                else:
+                                    assistant_message["content"] = guidance
+                            except Exception:
+                                pass
                         
                     except Exception:
                         pass
@@ -514,6 +608,12 @@ class InteractiveChatApp(App):
                     pass
 
                 if filtered_tool_calls:
+                    # 限制每轮仅执行一次工具调用，减少过度调用
+                    try:
+                        filtered_tool_calls = filtered_tool_calls[:1]
+                        self.notify("🎯 为提升精准度：本轮仅执行1次工具调用并随后进行思考", severity="success", timeout=3)
+                    except Exception:
+                        pass
                     assistant_message["tool_calls"] = filtered_tool_calls
                     # 调试：列出工具名
                     try:
@@ -530,33 +630,24 @@ class InteractiveChatApp(App):
                     
                 messages.append(assistant_message)
                 
-                # 显示AI响应
-                if response.content:
-                    # 计算AI响应的token统计
-                    assistant_msg_dict = {"role": "assistant", "content": response.content}
-                    # 使用当前messages作为上下文（不包括即将添加的assistant消息）
-                    context_for_assistant = messages[:-1] if messages else []
-                    assistant_token_stats = calculate_token_stats(
-                        current_message=assistant_msg_dict,
-                        context_messages=context_for_assistant
-                    )
-                    
-                    chat_history.add_message("assistant", response.content, token_stats=assistant_token_stats)
-
-                # 若使用了fallback提示（content 由我们填充），也输出到聊天区
+                # 显示AI响应（优先使用可能已追加指引的 assistant_message 内容）
                 try:
-                    if (assistant_message.get("content") or "").strip() and not (response.content or "").strip():
-                        assistant_msg_dict = {"role": "assistant", "content": assistant_message["content"]}
+                    assistant_content = (assistant_message.get("content") or "")
+                    if assistant_content.strip():
+                        assistant_msg_dict = {"role": "assistant", "content": assistant_content}
+                        # 使用当前messages作为上下文（不包括即将添加的assistant消息）
                         context_for_assistant = messages[:-1] if messages else []
                         assistant_token_stats = calculate_token_stats(
                             current_message=assistant_msg_dict,
                             context_messages=context_for_assistant
                         )
-                        chat_history.add_message("assistant", assistant_message["content"], token_stats=assistant_token_stats)
+                        chat_history.add_message("assistant", assistant_content, token_stats=assistant_token_stats)
                 except Exception:
                     pass
                 
                 # 处理工具调用（仅执行已启用的工具）
+                # 仅在允许工具且确实有调用时执行
+                # 仅在允许工具且确实有调用时执行
                 if filtered_tool_calls:
                     # 异步执行所有工具调用
                     tool_results = await function_executor.execute_from_tool_calls_async(filtered_tool_calls)
@@ -623,6 +714,8 @@ class InteractiveChatApp(App):
                                 "content": error_msg
                             }
                             messages.append(tool_message)
+                            # 工具失败：本次用户请求周期内屏蔽后续强制重试与重复调用
+                            block_tool_retry_for_current_query = True
                             # 调试：工具执行失败
                             try:
                                 self.notify(f"❌ 工具 {func_name} 执行失败：{error_msg}", severity="warning", timeout=4, markup=False)
@@ -667,8 +760,31 @@ class InteractiveChatApp(App):
                             self.notify(f"🧪 响应片段: {snippet}", timeout=5, markup=False)
                     except Exception:
                         pass
+                    # 非工具轮次或模型未给出工具调用：结束本次响应
                     break
                     
+            # 若达到迭代上限，给出明确提示并在聊天中写入说明
+            if iteration >= max_iterations:
+                try:
+                    self.notify(
+                        f"⚠️ 工具执行次数已达到上限（{max_iterations}），已停止继续。",
+                        severity="warning",
+                        timeout=5
+                    )
+                except Exception:
+                    pass
+                try:
+                    chat_history.add_message(
+                        "assistant",
+                        (
+                            f"工具执行次数已达到上限（{max_iterations}）。"
+                            "如需继续，请输入“继续”让我接着执行，"
+                            "或按 Ctrl+T 打开工具列表启用/调整所需工具后再试。"
+                        )
+                    )
+                except Exception:
+                    pass
+            
             # 更新对话历史
             self.conversation_history = messages
             
@@ -802,7 +918,7 @@ class InteractiveChatApp(App):
         self.current_session = None
         self._chat_in_progress = False
         self._add_welcome_message()
-        self.notify("对话历史已清空")
+        self.notify("对话历史已清空", severity="success")
         
     def action_show_tools(self) -> None:
         """显示工具列表"""
@@ -819,7 +935,7 @@ class InteractiveChatApp(App):
             self.enabled_tools = selected
             # 简单提示当前启用工具
             names_preview = ", ".join(list(selected)[:6]) if selected else "(无)"
-            self.notify(f"✅ 已更新启用工具：{names_preview}", timeout=4)
+            self.notify(f"✅ 已更新启用工具：{names_preview}", timeout=4, severity="success")
         except Exception as e:
             self.notify(f"更新启用工具失败: {e}", severity="error")
         
@@ -896,7 +1012,8 @@ class InteractiveChatApp(App):
             elif message["role"] == "assistant":
                 chat_history.add_message("assistant", message["content"])
         
-        self.notify(f"已加载会话: {session.get_display_title()}")
+        # 加载完成后提示一次
+        self.notify(f"已加载会话: {session.get_display_title()}", severity="success")
     
     def _save_current_session(self):
         """保存当前会话"""
