@@ -1,6 +1,7 @@
 """UI组件包"""
 
 from .message_widget import MessageWidget, StreamingMessageWidget, ToolCallWidget
+from .message_actions_widget import MessageActions
 from .input_widget import CustomTextArea, ChatInputWidget
 from .chat_history_widget import ChatHistoryWidget
 from .model_selector_widget import ModelSelectorWidget
@@ -13,6 +14,7 @@ __all__ = [
     "MessageWidget",
     "StreamingMessageWidget", 
     "ToolCallWidget",
+    "MessageActions",
     "CustomTextArea",
     "ChatInputWidget",
     "ChatHistoryWidget",
