@@ -87,7 +87,6 @@ class ModelConfigForm(Container):
             with Horizontal(classes="form-row"):
                 yield Label("模型名称:", classes="form-label")
                 yield Input(
-                    placeholder="输入模型名称",
                     id="name_input",
                     classes="form-input"
                 )
@@ -111,7 +110,6 @@ class ModelConfigForm(Container):
             with Horizontal(classes="form-row"):
                 yield Label("API端点:", classes="form-label")
                 yield Input(
-                    placeholder="https://api.example.com/v1/chat/completions",
                     id="endpoint_input",
                     classes="form-input"
                 )
@@ -119,7 +117,6 @@ class ModelConfigForm(Container):
             with Horizontal(classes="form-row"):
                 yield Label("API密钥:", classes="form-label")
                 yield Input(
-                    placeholder="输入API密钥",
                     password=True,
                     id="api_key_input",
                     classes="form-input"
@@ -128,7 +125,6 @@ class ModelConfigForm(Container):
             with Horizontal(classes="form-row"):
                 yield Label("模型标识:", classes="form-label")
                 yield Input(
-                    placeholder="gpt-3.5-turbo",
                     id="model_input",
                     classes="form-input"
                 )
@@ -158,17 +154,23 @@ class ModelConfigForm(Container):
                     id="timeout_input",
                     classes="form-input"
                 )
+
+            with Horizontal(classes="form-row"):
+                yield Label("最大迭代次数:", classes="form-label")
+                yield Input(
+                    value="20",
+                    id="max_iterations_input",
+                    classes="form-input"
+                )
             
             with Collapsible(title="请求头设置", collapsed=True):
                 yield TextArea(
-                    placeholder='{"Content-Type": "application/json"}',
                     id="headers_textarea",
                     classes="form-textarea"
                 )
             
             with Collapsible(title="额外参数", collapsed=True):
                 yield TextArea(
-                    placeholder='{"stream": true}',
                     id="extra_params_textarea",
                     classes="form-textarea"
                 )
@@ -196,6 +198,10 @@ class ModelConfigForm(Container):
         self.query_one("#max_tokens_input", Input).value = str(form_data.max_tokens)
         self.query_one("#temperature_input", Input).value = str(form_data.temperature)
         self.query_one("#timeout_input", Input).value = str(form_data.timeout)
+        try:
+            self.query_one("#max_iterations_input", Input).value = str(getattr(form_data, 'max_iterations', 20))
+        except Exception:
+            self.query_one("#max_iterations_input", Input).value = "20"
         
         # 填充JSON字段
         if form_data.headers:
@@ -229,6 +235,11 @@ class ModelConfigForm(Container):
             form_data.timeout = int(self.query_one("#timeout_input", Input).value)
         except ValueError:
             form_data.timeout = 300
+
+        try:
+            form_data.max_iterations = int(self.query_one("#max_iterations_input", Input).value)
+        except ValueError:
+            form_data.max_iterations = 20
         
         # JSON字段
         try:
