@@ -13,6 +13,7 @@ from textual.containers import Container
 from textual.widgets import Static, Button, Markdown
 from textual.reactive import reactive
 from textual.widget import Widget
+from .message_actions_widget import MessageActions
 
 from ..token_calculator import TokenStats, calculate_token_stats
 from typing import Optional, Dict
@@ -27,7 +28,75 @@ def safe_markdown_widget(content: str, **kwargs):
         return Static(content, **kwargs)
 
 
-class MessageWidget(Static):
+class ExpandableContentMixin:
+    """抽象可展开的文本内容逻辑：统一展开/收起、内容更新与复制"""
+
+    def _render_actions(self, is_long: bool, on_copy):
+        return MessageActions(
+            on_toggle=self._on_actions_toggle,
+            on_copy=on_copy,
+            is_long=is_long,
+            is_expanded=self.is_expanded,
+            unique_id=self.unique_id,
+            id=f"message-actions-{self.unique_id}",
+        )
+
+    def _update_text_content(
+        self,
+        text: str,
+        is_markdown: bool,
+        content_id: str,
+        max_length: int,
+        prefix: str = "",
+    ):
+        """统一更新文本内容组件（支持Markdown/Static），并在必要时挂载新组件"""
+        try:
+            content_widget = self.query_one(
+                f"#{content_id}", Markdown if is_markdown else Static
+            )
+        except Exception:
+            content_widget = None
+
+        display_text = prefix + (
+            text[:max_length] + "..." if len(text) > max_length and not self.is_expanded else text
+        )
+
+        if content_widget:
+            content_widget.update(display_text)
+        else:
+            try:
+                anchor = self.query_one(f"#message-actions-{self.unique_id}")
+            except Exception:
+                anchor = None
+            if is_markdown:
+                new_widget = safe_markdown_widget(
+                    display_text, classes="message-content", id=content_id
+                )
+            else:
+                new_widget = Static(
+                    display_text, classes="message-content", id=content_id, markup=False
+                )
+            if anchor:
+                self.mount(new_widget, before=anchor)
+            else:
+                self.mount(new_widget)
+
+    def _copy_text_to_clipboard(self, text: str):
+        try:
+            pyperclip.copy(text or "")
+            # 复制成功提示
+            if hasattr(self, "notify"):
+                self.notify("内容已复制到剪贴板", severity="success")
+            elif hasattr(self.app, "notify"):
+                self.app.notify("内容已复制到剪贴板", severity="success")
+        except Exception as e:
+            if hasattr(self, "notify"):
+                self.notify(f"复制失败: {str(e)}", severity="error")
+            elif hasattr(self.app, "notify"):
+                self.app.notify(f"复制失败: {str(e)}", severity="error")
+
+
+class MessageWidget(ExpandableContentMixin, Static):
     """单条消息显示组件"""
     
     def __init__(self, role: str, content: str, timestamp: str = None, 
@@ -65,119 +134,56 @@ class MessageWidget(Static):
             
             # 检查内容长度
             is_long = len(self.content) > 500
-            
+
+            # 内容展示（统一逻辑：根据 is_expanded 状态截断/展示）
             if self.role == "assistant":
-                # AI消息使用安全的Markdown渲染
                 if is_long and not self.is_expanded:
                     truncated_content = self.content[:500] + "..."
                     yield safe_markdown_widget(truncated_content, classes="message-content", id=f"message-content-{self.unique_id}")
-                    yield Button("点击查看完整消息", id=f"expand-message-button-{self.unique_id}", classes="expand-button")
                 else:
                     yield safe_markdown_widget(self.content, classes="message-content", id=f"message-content-{self.unique_id}")
-                    if is_long and self.is_expanded:
-                        yield Button("收起", id=f"collapse-message-button-{self.unique_id}", classes="expand-button")
             else:
-                # 用户消息使用普通文本
                 if is_long and not self.is_expanded:
                     truncated_content = self.content[:500] + "..."
                     yield Static(truncated_content, classes="message-content", id=f"message-content-{self.unique_id}", markup=False)
-                    yield Button("点击查看完整消息", id=f"expand-message-button-{self.unique_id}", classes="expand-button")
                 else:
                     yield Static(self.content, classes="message-content", id=f"message-content-{self.unique_id}", markup=False)
-                    if is_long and self.is_expanded:
-                        yield Button("收起", id=f"collapse-message-button-{self.unique_id}", classes="expand-button")
-            
-            # 添加复制按钮
-            yield Button("📋 复制", id=f"copy-message-button-{self.unique_id}", classes="copy-button")
-            
+
+            # 操作组件：复制 + 展开/收起（统一）
+            yield self._render_actions(is_long, on_copy=self._copy_message_content)
+
             # 添加token统计显示
             yield self._create_token_stats_widget()
     
     def on_button_pressed(self, event: Button.Pressed) -> None:
-        """处理按钮点击事件"""
-        if event.button.id == f"expand-message-button-{self.unique_id}":
-            self.is_expanded = True
-            self._update_message_content()
-        elif event.button.id == f"collapse-message-button-{self.unique_id}":
-            self.is_expanded = False
-            self._update_message_content()
-        elif event.button.id == f"copy-message-button-{self.unique_id}":
-            self._copy_message_content()
+        """消息按钮事件已统一由 MessageActions 处理"""
+        pass
+
+    def _on_actions_toggle(self, expanded: bool):
+        """供 MessageActions 回调：切换展开状态"""
+        self.is_expanded = expanded
+        self._update_message_content()
     
     def _update_message_content(self):
-        """更新消息内容显示"""
-        # 更安全的方式：先查找现有组件，如果存在则更新内容，否则创建新组件
-        is_long = len(self.content) > 500
-        
-        # 处理内容组件
-        try:
-            if self.role == "assistant":
-                content_widget = self.query_one(f"#message-content-{self.unique_id}", Markdown)
-            else:
-                content_widget = self.query_one(f"#message-content-{self.unique_id}", Static)
-            # 更新现有组件的内容
-            if self.role == "assistant":
-                if is_long and not self.is_expanded:
-                    truncated_content = self.content[:500] + "..."
-                    content_widget.update(truncated_content)
-                else:
-                    content_widget.update(self.content)
-            else:
-                if is_long and not self.is_expanded:
-                    truncated_content = self.content[:500] + "..."
-                    content_widget.update(truncated_content)
-                else:
-                    content_widget.update(self.content)
-        except:
-            # 如果组件不存在，创建新的
-            if self.role == "assistant":
-                if is_long and not self.is_expanded:
-                    truncated_content = self.content[:500] + "..."
-                    self.mount(safe_markdown_widget(truncated_content, classes="message-content", id=f"message-content-{self.unique_id}"))
-                else:
-                    self.mount(safe_markdown_widget(self.content, classes="message-content", id=f"message-content-{self.unique_id}"))
-            else:
-                if is_long and not self.is_expanded:
-                    truncated_content = self.content[:500] + "..."
-                    self.mount(Static(truncated_content, classes="message-content", id=f"message-content-{self.unique_id}"))
-                else:
-                    self.mount(Static(self.content, classes="message-content", id=f"message-content-{self.unique_id}"))
-        
-        # 处理按钮组件
-        # 移除所有相关按钮（包括复制按钮）
-        for button_id in [f"expand-message-button-{self.unique_id}", f"collapse-message-button-{self.unique_id}", f"copy-message-button-{self.unique_id}"]:
-            try:
-                button_widget = self.query_one(f"#{button_id}")
-                button_widget.remove()
-            except:
-                pass
-        
-        # 根据状态添加相应的按钮
-        if is_long:
-            if not self.is_expanded:
-                self.mount(Button("点击查看完整消息", id=f"expand-message-button-{self.unique_id}", classes="expand-button"))
-            else:
-                self.mount(Button("收起", id=f"collapse-message-button-{self.unique_id}", classes="expand-button"))
-        
-        # 重新添加复制按钮
-        self.mount(Button("📋 复制", id=f"copy-message-button-{self.unique_id}", classes="copy-button"))
-    
+        """更新消息内容显示（仅更新内容，操作按钮由 MessageActions 管理）"""
+        is_markdown = self.role == "assistant"
+        self._update_text_content(
+            text=self.content,
+            is_markdown=is_markdown,
+            content_id=f"message-content-{self.unique_id}",
+            max_length=500,
+            prefix="",
+        )
+
     def _copy_message_content(self):
         """复制消息内容到剪贴板"""
-        try:
-            pyperclip.copy(self.content)
-            # 通过app发送通知
-            if hasattr(self.app, 'notify'):
-                self.app.notify(f"已复制消息内容")
-        except Exception as e:
-            if hasattr(self.app, 'notify'):
-                self.app.notify(f"复制失败: {str(e)}")
-    
+        self._copy_text_to_clipboard(self.content)
+
     def _create_token_stats_widget(self) -> Static:
         """创建token统计显示组件"""
         stats_text = f"[dim]🔢 {str(self.token_stats)}[/dim]"
         return Static(stats_text, classes="token-stats", id=f"token-stats-{self.unique_id}")
-    
+
     def update_token_stats(self, new_stats: TokenStats):
         """更新token统计信息"""
         self.token_stats = new_stats
@@ -185,7 +191,7 @@ class MessageWidget(Static):
             stats_widget = self.query_one(f"#token-stats-{self.unique_id}", Static)
             stats_text = f"[dim]🔢 {str(new_stats)}[/dim]"
             stats_widget.update(stats_text)
-        except:
+        except Exception:
             # 如果组件不存在，重新创建
             self.mount(self._create_token_stats_widget())
 
@@ -268,19 +274,22 @@ class StreamingMessageWidget(Static):
         try:
             content = "".join(self.content_chunks)
             pyperclip.copy(content)
-            # 通过app发送通知
-            if hasattr(self.app, 'notify'):
-                self.app.notify(f"已复制消息内容")
+            if hasattr(self, "notify"):
+                self.notify("内容已复制到剪贴板", severity="success")
+            elif hasattr(self.app, "notify"):
+                self.app.notify("内容已复制到剪贴板", severity="success")
         except Exception as e:
-            if hasattr(self.app, 'notify'):
-                self.app.notify(f"复制失败: {str(e)}")
+            if hasattr(self, "notify"):
+                self.notify(f"复制失败: {str(e)}", severity="error")
+            elif hasattr(self.app, 'notify'):
+                self.app.notify(f"复制失败: {str(e)}", severity="error")
         
     def get_final_content(self) -> str:
         """获取最终内容"""
         return "".join(self.content_chunks)
 
 
-class ToolCallWidget(Static):
+class ToolCallWidget(ExpandableContentMixin, Static):
     """工具调用显示组件"""
     
     def __init__(self, tool_name: str, arguments: str, result: str = None, success: bool = True, result_obj: Optional[Dict] = None, **kwargs):
@@ -293,80 +302,119 @@ class ToolCallWidget(Static):
         self.is_expanded = False
         # 为每个实例生成唯一ID前缀，避免多个实例间的ID冲突
         self.unique_id = str(uuid.uuid4())[:8]
+        self.max_length = 500
         
     def compose(self) -> ComposeResult:
         """构建工具调用UI"""
         status_color = "green" if self.success else "red"
         status_text = "✓" if self.success else "✗"
         
+        # 将结果与操作按钮一并置于工具容器（黄色框）内
         with Container(classes="tool-call-container"):
             yield Static(f"[cyan]🔧 调用工具: {self.tool_name}[/cyan] [{status_color}]{status_text}[/{status_color}]", classes="tool-header")
             yield Static(f"[dim]参数: {self.arguments}[/dim]", classes="tool-args")
             
-        # 优先渲染对象结果（如图表组件或任意Textual组件）
-        if self.result_obj and isinstance(self.result_obj, Widget):
-            self.notify("图表可视化结果已显示")
-            # 使用包装容器居中显示结果组件
-            with Container(classes="tool-result-wrapper"):
-                yield self.result_obj
-        elif isinstance(self.result, Widget):
-            # 兼容旧逻辑：如果结果直接是组件实例
-            self.notify("图表可视化结果已显示")
-            with Container(classes="tool-result-wrapper"):
-                yield self.result
-        elif self.result:
-            # 文本结果的显示（支持展开/收起）
-            lines = self.result.split('\n')
-            is_long = len(lines) > 4
-            if is_long and not self.is_expanded:
-                # 只显示前4行，并添加省略号
-                display_result = '\n'.join(lines[:4]) + "\n..."
-                yield Static(f"结果: {display_result}", classes="tool-result", id=f"tool-result-content-{self.unique_id}", markup=False)
-                yield Button("点击查看完整结果", id=f"expand-button-{self.unique_id}", classes="expand-button")
-            else:
-                yield Static(f"结果: {self.result}", classes="tool-result", id=f"tool-result-content-{self.unique_id}", markup=False)
-                if is_long and self.is_expanded:
-                    yield Button("收起", id=f"collapse-button-{self.unique_id}", classes="expand-button")
+            # 优先渲染对象结果（如图表组件或任意Textual组件）
+            if self.result_obj and isinstance(self.result_obj, Widget):
+                self.notify("图表可视化结果已显示")
+                # 使用包装容器居中显示结果组件
+                with Container(classes="tool-result-wrapper"):
+                    yield self.result_obj
+            elif isinstance(self.result, Widget):
+                # 兼容旧逻辑：如果结果直接是组件实例
+                self.notify("图表可视化结果已显示")
+                with Container(classes="tool-result-wrapper"):
+                    yield self.result
+            elif self.result:
+                # 文本结果显示（统一逻辑：按字符长度截断）
+                is_long = len(self.result) > 500
+                if is_long and not self.is_expanded:
+                    truncated = self.result[:500] + "..."
+                    yield Static(
+                        f"结果: {truncated}",
+                        classes="tool-result",
+                        id=f"tool-result-content-{self.unique_id}",
+                        markup=False,
+                    )
+                else:
+                    yield Static(
+                        f"结果: {self.result}",
+                        classes="tool-result",
+                        id=f"tool-result-content-{self.unique_id}",
+                        markup=False,
+                    )
+
+                # 操作组件：复制 + 展开/收起（统一）放在容器内部
+                yield self._render_actions(is_long, on_copy=self._copy_result_content)
+
     
     def on_button_pressed(self, event: Button.Pressed) -> None:
-        """处理按钮点击事件"""
-        if event.button.id == f"expand-button-{self.unique_id}":
-            self.is_expanded = True
-            self._update_content()
-        elif event.button.id == f"collapse-button-{self.unique_id}":
-            self.is_expanded = False
-            self._update_content()
+        """工具结果按钮事件由 MessageActions 处理"""
+        pass
+
+    def _on_actions_toggle(self, expanded: bool):
+        """供 MessageActions 回调：切换展开状态"""
+        self.is_expanded = expanded
+        self._update_content()
+
+    def _copy_result_content(self):
+        """复制工具结果到剪贴板"""
+        self._copy_text_to_clipboard(self.result or "")
     
     def _update_content(self):
         """更新内容显示"""
-        # 移除现有的结果和按钮组件
-        result_widgets = self.query(f"#tool-result-content-{self.unique_id}")
-        for widget in result_widgets:
-            widget.remove()
+        if not self.result:
+            return
+        self._update_text_content(
+            text=self.result,
+            is_markdown=False,
+            content_id=f"tool-result-content-{self.unique_id}",
+            max_length=self.max_length,
+            prefix="结果: ",
+        )
+
+        # 优先就地更新现有结果组件，避免影响操作条
+        try:
+            content_widget = self.query_one(
+                f"#tool-result-content-{self.unique_id}", Static
+            )
+        except Exception:
+            content_widget = None
+
         
-        expand_buttons = self.query(f"#expand-button-{self.unique_id}")
-        for widget in expand_buttons:
-            widget.remove()
-            
-        collapse_buttons = self.query(f"#collapse-button-{self.unique_id}")
-        for widget in collapse_buttons:
-            widget.remove()
-        
-        # 使用call_after_refresh确保移除操作完成后再挂载新组件
-        self.call_after_refresh(self._mount_new_content)
-    
-    def _mount_new_content(self):
-        """在移除操作完成后挂载新内容"""
+
         if self.result:
-            # 检查是否需要截断（按行数判断，超过4行）
-            lines = self.result.split('\n')
-            is_long = len(lines) > 4
-            if is_long and not self.is_expanded:
-                # 只显示前4行，并添加省略号
-                display_result = '\n'.join(lines[:4]) + "\n..."
-                self.mount(Static(f"结果: {display_result}", classes="tool-result", id=f"tool-result-content-{self.unique_id}", markup=False))
-                self.mount(Button("点击查看完整结果", id=f"expand-button-{self.unique_id}", classes="expand-button"))
+            is_long = len(self.result) > self.max_length
+            if content_widget:
+                if is_long and not self.is_expanded:
+                    truncated = self.result[:self.max_length] + "..."
+                    content_widget.update(f"结果: {truncated}")
+                else:
+                    content_widget.update(f"结果: {self.result}")
             else:
-                self.mount(Static(f"结果: {self.result}", classes="tool-result", id=f"tool-result-content-{self.unique_id}", markup=False))
-                if is_long and self.is_expanded:
-                    self.mount(Button("收起", id=f"collapse-button-{self.unique_id}", classes="expand-button"))
\ No newline at end of file
+                # 若不存在结果组件，则创建；为保证位置稳定，尽量插入到操作条之前
+                try:
+                    anchor = self.query_one(f"#message-actions-{self.unique_id}")
+                except Exception:
+                    anchor = None
+                if is_long and not self.is_expanded:
+                    truncated = self.result[:self.max_length] + "..."
+                    new_widget = Static(
+                        f"结果: {truncated}",
+                        classes="tool-result",
+                        id=f"tool-result-content-{self.unique_id}",
+                        markup=False,
+                    )
+                else:
+                    new_widget = Static(
+                        f"结果: {self.result}",
+                        classes="tool-result",
+                        id=f"tool-result-content-{self.unique_id}",
+                        markup=False,
+                    )
+                if anchor:
+                    self.mount(new_widget, before=anchor)
+                else:
+                    self.mount(new_widget)
+
+        
\ No newline at end of file
