@@ -138,11 +138,20 @@ class ToolsListModal(ModalScreen):
             self.post_message(self.ToolsSaved(selected_tools=selected))
             self.dismiss()
 
+    def on_key(self, event) -> None:
+        """支持 ESC 关闭弹窗"""
+        if getattr(event, "key", None) == "escape":
+            self.dismiss()
+            try:
+                event.prevent_default()
+            except Exception:
+                pass
+
 
 class ContextWindowModal(ModalScreen):
     """上下文查看弹窗
     
-    展示当前会话上下文、系统提示词，以及为AI请求准备的上下文。
+    仅展示用户与模型的对话内容。
     """
 
     def compose(self) -> ComposeResult:
@@ -156,131 +165,45 @@ class ContextWindowModal(ModalScreen):
     def on_mount(self) -> None:
         content = self.query_one("#context-content", ScrollableContainer)
 
-        # 系统提示词
-        try:
-            system_prompt = getattr(self.app.ai_client, "system_prompt", "") or "(无系统提示词)"
-        except Exception:
-            system_prompt = "(无法获取系统提示词)"
-
-        system_block = Static(
-            f"系统提示词\n{system_prompt}",
-            classes="context-block",
-            markup=False
-        )
-        content.mount(system_block)
-
-        # 已启用工具列表
-        try:
-            enabled = list(getattr(self.app, "enabled_tools", set()) or [])
-            enabled.sort()
-            tools_text = ["已启用工具"]
-            if not enabled:
-                tools_text.append("暂无启用的工具（将不进行函数调用）")
-            else:
-                tools_text.append(f"数量: {len(enabled)}")
-                tools_text.extend([f"- {n}" for n in enabled])
-            content.mount(Static("\n".join(tools_text), classes="context-block", markup=False))
-        except Exception:
-            pass
-
-        # 原始会话消息（完整，不截断），并区分用户输入与模型返回
+        # 只展示用户与模型的对话内容
         try:
             raw_messages = list(self.app.conversation_history or [])
         except Exception:
             raw_messages = []
 
-        # 时间线（完整）
-        timeline_lines = ["会话时间线（完整）"]
-        if not raw_messages:
-            timeline_lines.append("暂无消息")
-        else:
-            timeline_lines.append(f"总消息数: {len(raw_messages)}")
-            for i, msg in enumerate(raw_messages, start=1):
-                role = msg.get("role", "unknown")
-                label = {
-                    "system": "系统提示",
-                    "user": "用户输入",
-                    "assistant": "模型返回",
-                    "tool": "工具结果"
-                }.get(role, role)
-                content_full = (msg.get("content", "") or "").strip()
-                timeline_lines.append(f"{i}. [{label}] {content_full}")
-        content.mount(Static("\n".join(timeline_lines), classes="context-block", markup=False))
+        conv_messages = [m for m in raw_messages if m.get("role") in ("user", "assistant")]
 
-        # 用户输入（完整）
-        user_lines = ["用户输入（完整）"]
-        user_messages = [m for m in raw_messages if (m.get("role") == "user")]
-        if not user_messages:
-            user_lines.append("暂无用户输入")
-        else:
-            for i, msg in enumerate(user_messages, start=1):
-                content_full = (msg.get("content", "") or "").strip()
-                user_lines.append(f"{i}. {content_full}")
-        content.mount(Static("\n".join(user_lines), classes="context-block", markup=False))
+        if not conv_messages:
+            content.mount(Static("暂无对话内容", classes="empty-message", markup=False))
+            return
 
-        # 模型返回（完整）
-        assistant_lines = ["模型返回（完整）"]
-        assistant_messages = [m for m in raw_messages if (m.get("role") == "assistant")]
-        if not assistant_messages:
-            assistant_lines.append("暂无模型返回")
-        else:
-            for i, msg in enumerate(assistant_messages, start=1):
-                content_full = (msg.get("content", "") or "").strip()
-                assistant_lines.append(f"{i}. {content_full}")
-        content.mount(Static("\n".join(assistant_lines), classes="context-block", markup=False))
+        # 准备要显示的内容行
+        prepared_lines = []
+        
+        # 逐条渲染消息，使用不同样式区分用户与模型
+        for msg in conv_messages:
+            role = msg.get("role")
+            content_full = (msg.get("content", "") or "").strip()
+            role_label = "用户" if role == "user" else "模型"
 
-        # 压缩建议
-        try:
-            recommendation = self.app.context_manager.get_compression_recommendation(raw_messages)
-        except Exception:
-            recommendation = {"should_compress": False, "estimated_tokens": 0}
+            # 修复：先创建子组件，然后一起挂载到容器
+            from textual.containers import Container as TContainer
+            item = TContainer(classes=f"message-container {'user-message' if role == 'user' else 'assistant-message'}")
+            
+            # 先挂载容器到父容器
+            content.mount(item)
+            
+            # 然后向容器中添加子组件
+            item.mount(Static(role_label, classes="message-header", markup=False))
+            item.mount(Static(content_full, classes="message-content", markup=False))
+            
+            # 同时为准备的内容添加文本行
+            prepared_lines.append(f"[{role_label}] {content_full}")
 
-        rec_block = Static(
-            "\n".join([
-                "压缩建议",
-                f"是否建议压缩: {'是' if recommendation.get('should_compress') else '否'}",
-                f"估算当前token: {recommendation.get('estimated_tokens', 0)}",
-            ]),
-            classes="context-block",
-            markup=False
-        )
-        content.mount(rec_block)
-
-        # 为AI请求准备的上下文（压缩后）
-        try:
-            # 准备一个会话对象
-            session: ChatSession = self.app.current_session or ChatSession.create_new()
-            if not session.messages:
-                session.update_messages(raw_messages)
-            prepared_messages = self.app.session_context_manager.prepare_for_ai_request(session, max_context_tokens=4000) or []
-        except Exception:
-            prepared_messages = []
-
-        # 记录上下文准备情况
-        try:
-            logger = logging.getLogger("ketacli.textual")
-            logger.debug(f"[context-modal] 原始消息数={len(raw_messages)}, 预处理后消息数={len(prepared_messages)}")
-        except Exception:
-            pass
-
-        prepared_lines = ["AI请求上下文（压缩后/裁剪后）"]
-        if not prepared_messages:
-            prepared_lines.append("暂无上下文（可能没有消息或准备失败）")
-            try:
-                logging.getLogger("ketacli.textual").warning("[context-modal] 预处理上下文为空：可能没有消息或准备失败")
-            except Exception:
-                pass
-        else:
-            prepared_lines.append(f"上下文消息数: {len(prepared_messages)}")
-            for i, msg in enumerate(prepared_messages, start=1):
-                role = msg.get("role", "unknown")
-                content_preview = (msg.get("content", "") or "").strip()
-                if len(content_preview) > 200:
-                    content_preview = content_preview[:200] + "..."
-                prepared_lines.append(f"{i}. [{role}] {content_preview}")
-
-        prepared_block = Static("\n".join(prepared_lines), classes="context-block", markup=False)
-        content.mount(prepared_block)
+        # 如果有准备的内容，添加汇总块
+        if prepared_lines:
+            prepared_block = Static("\n".join(prepared_lines), classes="context-block", markup=False)
+            content.mount(prepared_block)
 
     def on_button_pressed(self, event: Button.Pressed) -> None:
         if event.button.id == "close-button":
@@ -441,7 +364,7 @@ class SessionHistoryModal(ModalScreen):
         
         session = target_widget.session
         if self.session_manager.delete_session(session.session_id):
-            self.notify(f"已删除会话: {session.title}")
+            self.notify(f"已删除会话: {session.title}", severity="success")
             self._load_sessions()  # 重新加载列表
             # 重新设置焦点到第一个会话
             self.call_after_refresh(self._focus_first_session)
@@ -495,7 +418,13 @@ class SessionItemWidget(Static):
         if event.key == "enter":
             # Enter键加载会话
             self.post_message(self.SessionClicked(self.session))
+            # 阻止事件冒泡到父级，以避免父Modal同时处理Enter导致重复触发
             event.prevent_default()
+            try:
+                event.stop()
+            except Exception:
+                # 某些环境下event可能不支持stop，忽略即可
+                pass
     
 
     
